#ifndef UTILITIES_EXCEPTIONS_EXCEPTIONS_H
#define UTILITIES_EXCEPTIONS_EXCEPTIONS_H

// Generic
#include "Exception.h"
#include "InvalidArgumentException.h"
#include "InvalidOperationException.h"
#include "OutOfMemoryException.h"
#include "StackUnderflowException.h"

// Numeric
#include "NumericException.h"
#include "OverflowException.h"
#include "IntegerOverflowException.h"
#include "RoundoffException.h"
#include "MaxIterationsException.h"

// Assertions
#include "Assertions.h"

#endif
